@@ -17,9 +17,7 @@ def main():
                              'oke mask tiffs should be named following this example: If <scans_dir> has a file called'
                              'scan1.tif, the corresponding stroke mask should be named scan1_stroke_mask.tif')
 
-    args = parser.parse_args()
-    print("Arguments: " + str(args._))
-    args = vars(args)
+    args = vars(parser.parse_args())
     crop_all_stacks(args)
     return 0
 
